Krige admixture values
tess_krig.RdKrige admixture values
Usage
tess_krig(
qmat,
coords,
grid = NULL,
correct_kriged_Q = TRUE,
model = c("Sph", "Exp", "Gau", "Ste")
)Arguments
- qmat
qmatrix
- coords
coordinates of samples as sf points, a two-column matrix, or a data.frame representing x and y coordinates (see Details for important information about projections)
- grid
Optional SpatRaster for kriging (defaults to NULL)
- correct_kriged_Q
whether to correct kriged Q values so values greater than 1 are set to 1 and values less than 0 are set to 0 (defaults to TRUE)
- model
variogram model(s) to test during automatic kriging. Passed to
autoKrige. Defaults toc("Sph", "Exp", "Gau", "Ste"). To restrict fitting to specific models, provide one or more model names (e.g.,c("Sph", "Exp")).